//
//  TPPCollectionViewController.m
//  PhotoPhun
//
//  Created by Gabe Nadel on 6/13/16.
//  Copyright © 2016 Gabe Nadel. All rights reserved.
//

#import "TPPCollectionViewController.h"
#import "TPPUICollectionViewCell.h"

NSString *const DATA_VERSION_DATE = @"20160627";
NSString *const DATA_FORMAT = @"foursquare";

@implementation TPPCollectionViewController

-(void)viewDidLoad{
    self.collectionView.backgroundColor = [UIColor whiteColor];
    self.navigationController.navigationBar.topItem.title = @"PhotoPhun";
    
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    self.accessToken = [defaults stringForKey:@"accessToken"];
    
    if(self.accessToken == nil){
        //get token
        [SimpleAuth authorize:@"foursquare-web" completion:^(id responseObject, NSError *error) {
            NSLog(@"response: %@", responseObject);
            NSString *token = responseObject[@"credentials"][@"token"];
            NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
            [defaults setObject:token forKey:@"accessToken"];
            [defaults synchronize];
            
            [self refreshFoursquare];
            
        }];
        
    }
    else{
        //use token, get venue data
        [self refreshFoursquare];
}
}

-(void)refreshFoursquare{
    
    NSURLSession *session = [NSURLSession sharedSession];
    NSString *urlString = [[NSString alloc]initWithFormat:@"https://api.foursquare.com/v2/users/self/venuelikes/?oauth_token=%@&v=%@&m=%@", self.accessToken, DATA_VERSION_DATE, DATA_FORMAT];
    NSURL *url = [NSURL URLWithString:urlString];
    NSURLRequest *requst = [[NSURLRequest alloc]initWithURL:url];
    NSURLSessionDownloadTask *task = [session downloadTaskWithRequest:requst completionHandler:^(NSURL * _Nullable location, NSURLResponse * _Nullable response, NSError * _Nullable error) {
        
        NSData *data = [[NSData alloc]initWithContentsOfURL:location];
        NSDictionary *responseDict = [NSJSONSerialization JSONObjectWithData:data options:kNilOptions error:nil];
        self.likedArray = [responseDict valueForKeyPath:@"response.venues.items.id"];
        self.venueArray =[[NSMutableArray alloc]init];
        
        for(NSString *venueID in self.likedArray){
            NSString *urlStringVenue = [[NSString alloc]initWithFormat:@"https://api.foursquare.com/v2/venues/%@?oauth_token=%@&v=%@&m=%@", venueID, self.accessToken, DATA_VERSION_DATE, DATA_FORMAT];
            NSURL *urlVenue = [NSURL URLWithString:urlStringVenue];
            NSURLRequest *requestVenue = [[NSURLRequest alloc]initWithURL:urlVenue ];
            NSURLSessionDownloadTask *taskVenue = [session downloadTaskWithRequest:requestVenue completionHandler:^(NSURL * _Nullable location, NSURLResponse * _Nullable response, NSError * _Nullable error) {
                NSData *dataVenue = [[NSData alloc]initWithContentsOfURL:location];
                NSDictionary *responseDictVenue = [NSJSONSerialization JSONObjectWithData:dataVenue options:kNilOptions error:nil];
                [self.venueArray addObject:responseDictVenue];
                
                dispatch_async(dispatch_get_main_queue(), ^{
                    [self.collectionView reloadData];
                });
                
            }];
            
        [taskVenue resume];
            
        }
        
    }];
    [task resume];
    
    
}

-(void)refreshPhotos{
    
    NSURLSession *session = [NSURLSession sharedSession];
    NSURL *url = [NSURL URLWithString:@"https://swapi.co/api/people"];
    NSURLRequest *request = [NSURLRequest requestWithURL:url];
    
    NSURLSessionDownloadTask *task = [session downloadTaskWithRequest:request completionHandler:^(NSURL * _Nullable location, NSURLResponse * _Nullable response, NSError * _Nullable error) {
        
        NSString *responseText = [[NSString alloc]initWithContentsOfURL:location encoding:NSUTF8StringEncoding error:nil];
        
        NSLog(@"ResponseText: %@", responseText);
    }];
    
    [task resume];
    
}

-(NSInteger)numberOfSectionsInCollectionView:(UICollectionView *)collectionView{
    return 1;
}

-(NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section{
    return self.venueArray.count;
}

-(UICollectionViewCell*)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath{
    TPPUICollectionViewCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:@"PhotoPhunCell" forIndexPath:indexPath];
    cell.photoData = self.venueArray[indexPath.row];
    
    
    
    return cell;
}

@end
